@@ -7,6 +7,7 @@ from .callDirectionalTAD import *
 from .calldTADAllchr import *
 from .discrete import *
 from .stripe import *
+import os
 
 def CLI():
     parser = argparse.ArgumentParser(description="HiC1Dmetrics is python3-based tools to \
@@ -17,6 +18,7 @@ def CLI():
 
     #Function 1
     def func_basic(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         args.matrix = args.data
         if args.mode == "plot":
             if args.datatype == "rawhic":
@@ -59,7 +61,7 @@ def CLI():
         elif args.mode == "gd":
             codepath = os.path.dirname(os.path.realpath(__file__))
             gdcode = codepath+"/gd/makeDensity.sh"
-            os.system("sh "+gdcode+" -r "+str(args.resolution)+" -g "+args.data+" -t "+args.chromosome+" -o "+args.outname)
+            os.system("bash "+gdcode+" -r "+str(args.resolution)+" -g "+args.data+" -t "+args.chromosome+" -o "+args.outname)
         else:
             print("Unsupported mode"); exit(1)
     parser_basic = subparsers.add_parser("basic",help="Provide basic functions to visualize and handle Hi-C data.")
@@ -83,6 +85,7 @@ def CLI():
     #Function 2
     #=============================================================================
     def func_one(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         args.matrix = args.data
         if args.chromosome == "all":
             if not args.maxchr: print("Please sepcify the maximum chromosome"); exit(1)
@@ -135,6 +138,7 @@ def CLI():
     #Function 3
     #=============================================================================
     def func_two(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         args.matrix = args.data
         args.controlmatrix = args.controldata
 
@@ -185,20 +189,20 @@ def CLI():
     #Function 4
     #=============================================================================
     def func_types(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         args.matrix = args.data
         typelist = args.typelist.split(",")
         parameterlist = args.parameter.split(",")
         if not args.controlmatrix:
             if not set(typelist).issubset(["IS","CI","DI","SS","DLR","PC1","IES","IAS","IF"]):
                 print("Error: not supported"); exit(1)
-            if "IF" in typelist and args.datatype == "matrix": print("Error: IF required rawhic datatype"); exit(1)
+            if "IF" in typelist and args.datatype != "rawhic": print("Error: IF required rawhic datatype"); exit(1)
             ms = multiScore(args.matrix,args.resolution,args.chromosome)
             if not args.draw:
                 score = ms.allOneScore(typelist,parameterlist,datatype=args.datatype,gt=args.gt)
             elif args.draw:
                 score = ms.plotOneScore(typelist,parameterlist,datatype=args.datatype,gt=args.gt,start=args.start,end=args.end)
                 plt.savefig(args.outname+".pdf")
-            print(score.iloc[550:650,:])
             score.to_csv(args.outname + ".csv", sep="\t", header=True, index=False)
         elif args.controlmatrix:
             if not set(typelist).issubset(["ISC","CIC","SSC","deltaDLR","CD","IESC","IASC","IFC","DRF"]):
@@ -214,7 +218,6 @@ def CLI():
             elif args.draw:
                 score = ms.plotTwoScore(typelist,parameterlist,datatype=args.datatype,gt=args.gt,start=args.start,end=args.end)
                 plt.savefig(args.outname+".pdf")
-            print(score.iloc[550:650,:])
             score.to_csv(args.outname + ".csv", sep="\t", header=True, index=False)
 
         os.system("rm -rf MatrixTemp*")
@@ -228,7 +231,7 @@ def CLI():
     parser_types.add_argument("-p","--parameter",type=str,help="Parameter for indicated metrics",default=None,required=True)
     parser_types.add_argument('-c','--controlmatrix', type=str, help='Path of control matrix file from JuicerResult',default=None)
     parser_types.add_argument("-o","--outname",help="output name (default metrics)",type=str,default="multitypes_metrics")
-    parser_types.add_argument('--datatype',type=str,help="matrix or rawhic",default="matrix")
+    parser_types.add_argument('--datatype',type=str,help="Type of input data: [matrix(default),rawhic,cool].",default="matrix")
     parser_types.add_argument('--gt',type=str,help="genome table",default="")
     parser_types.add_argument("-d","--draw",action='store_true',help="Plot figure for candidate region",default=False)
     parser_types.add_argument('-s','--start',type=int,help="Start sites for plotting",default=0)
@@ -238,6 +241,7 @@ def CLI():
     #Function 5
     #=============================================================================
     def func_samples(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         if args.type == "IF" and args.datatype == "matrix": print("Error: IF required rawhic datatype"); exit(1)
         datafile = pd.read_csv(args.data,sep="\t",header=None)
         labels = list(datafile.iloc[:,0])
@@ -318,10 +322,15 @@ def CLI():
     #Function 6
     #=============================================================================
     def func_call(args):
+        if not os.path.exists(args.data):print("File does not exist");exit(1)
         args.matrix = args.data
-        if args.datatype == "rawhic" and args.mode != "hubs":
-            path = hic2matrix(args.matrix,args.resolution,args.chromosome,args.gt)
-            if args.controlmatrix: controlpath = hic2matrix(args.controlmatrix,args.resolution,args.chromosome,args.gt)
+        if args.datatype in ["rawhic",'cool'] and args.mode != "hubs":
+            if args.datatype == "rawhic":
+                path = hic2matrix(args.matrix,args.resolution,args.chromosome,args.gt)
+                if args.controlmatrix: controlpath = hic2matrix(args.controlmatrix,args.resolution,args.chromosome,args.gt)
+            elif args.datatype == "cool":
+                path = cool2matrix(args.matrix,args.resolution,args.chromosome,args.gt)
+                if args.controlmatrix: controlpath = cool2matrix(args.controlmatrix,args.resolution,args.chromosome,args.gt)
         else:
             path = args.matrix
             controlpath = args.controlmatrix
@@ -343,8 +352,8 @@ def CLI():
             rightdTAD.to_csv(args.outname + "_rightdTAD.csv", sep="\t", header=True, index=False)
         elif args.mode == "stripeTAD":
             st = stripeTAD(path,args.resolution,args.chromosome)
-            stripeTAD = st.callStripe(squareSize=300000)
-            stripeTAD.to_csv(args.outname + "_stripeTAD.csv", sep="\t", header=True, index=False)
+            sTAD = st.callStripe(squareSize=300000)
+            sTAD.to_csv(args.outname + "_stripeTAD.csv", sep="\t", header=True, index=False)
         elif args.mode == "stripe":
             st = call_stripe(path,args.resolution,args.chromosome)
             stripe = st.callStripe(squareSize=300000,strong_thresh=0.2)
@@ -367,7 +376,7 @@ def CLI():
     parser_call.add_argument("chromosome",type=str,help="Chromosome number.")
     parser_call.add_argument("-o","--outname",help="output name",type=str,default="defaultname")
     parser_call.add_argument('-c','--controlmatrix', type=str, help='Path of control matrix file from JuicerResult',default=None)
-    parser_call.add_argument('--datatype',type=str,help="matrix or rawhic",default="matrix")
+    parser_call.add_argument('--datatype',type=str,help="Type of input data: [matrix(default),rawhic,cool].",default="matrix")
     parser_call.add_argument('--gt',type=str,help="genome table",default="")
     parser_call.add_argument("-p","--parameter",type=str,help="Parameter for indicated mode",default=None)
     parser_call.set_defaults(func=func_call)
@@ -375,7 +384,7 @@ def CLI():
     parser.add_argument("-V","--version",help="Show h1d version",action='store_true',default=False)
     args = parser.parse_args()
     if args.version:
-        print("h1d version 0.1.19")
+        print("h1d version 0.1.21")
         exit(0)
     try:
         func = args.func
